debug/assert.hpp

The debug/assert.hpp header defines macros for preprocessing-time assertions.

#### Usage

#include <boost/preprocessor/debug/assert.hpp>

#### Contents

- BOOST_PP_ASSERT
- BOOST_PP_ASSERT_MSG

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)